package com.dzeio.openhealth.ui.browse

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.Settings
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.step.StepRepository
import com.dzeio.openhealth.data.weight.WeightRepository
import com.dzeio.openhealth.utils.Configuration
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class BrowseViewModel @Inject internal constructor(
    stepRepository: StepRepository,
    weightRepository: WeightRepository,
    private val config: Configuration
) : BaseViewModel() {

    private val _steps = MutableLiveData(0)
    val steps: LiveData<Int> = _steps

    private val _stepsGoal: MutableLiveData<Int?> = MutableLiveData()
    val stepsGoal: LiveData<Int?> = _stepsGoal

    private val _weight = MutableLiveData(0f)
    val weight: LiveData<Float> = _weight

    init {
        viewModelScope.launch {
            _steps.postValue(stepRepository.todaySteps())
        }

        viewModelScope.launch {
            weightRepository.lastWeight().collectLatest {
                if (it == null) {
                    return@collectLatest
                }
                _weight.postValue(it.weight)
            }
        }

        this._stepsGoal.postValue(
            config.getInt(Settings.STEPS_GOAL).value
        )
    }
}
