package com.dzeio.openhealth.ui.steps

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.LinearLayoutManager
import com.dzeio.charts.Entry
import com.dzeio.charts.series.BarSerie
import com.dzeio.openhealth.Application
import com.dzeio.openhealth.adapters.StepsAdapter
import com.dzeio.openhealth.core.BaseFragment
import com.dzeio.openhealth.databinding.FragmentStepsHomeBinding
import com.google.android.material.color.MaterialColors
import dagger.hilt.android.AndroidEntryPoint
import java.text.DateFormat
import java.util.Calendar
import java.util.Date
import java.util.Locale
import java.util.TimeZone

@AndroidEntryPoint
class StepsHomeFragment :
    BaseFragment<StepsHomeViewModel, FragmentStepsHomeBinding>(StepsHomeViewModel::class.java) {

    companion object {
        const val TAG = "${Application.TAG}/SHFragment"
    }

    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> FragmentStepsHomeBinding =
        FragmentStepsHomeBinding::inflate

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        viewModel.init()

        val recycler = binding.list

        val manager = LinearLayoutManager(requireContext())
        recycler.layoutManager = manager

        val adapter = StepsAdapter()
        adapter.onItemClick = {
//            findNavController().navigate(
//                WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterEdit(
//                    it.id
//                )
//            )
        }
        recycler.adapter = adapter

        val chart = binding.chart

        // setup serie
        val serie = BarSerie(chart).apply {
            barPaint.color = MaterialColors.getColor(
                requireView(),
                com.google.android.material.R.attr.colorPrimary
            )
            textPaint.color = MaterialColors.getColor(
                requireView(),
                com.google.android.material.R.attr.colorOnPrimary
            )
        }

        val errorColor = MaterialColors.getColor(
            requireView(),
            com.google.android.material.R.attr.colorError
        )

        chart.apply {
            series = arrayListOf(serie)
//            debug = true

            yAxis.apply {
                textLabel.color = MaterialColors.getColor(
                    requireView(),
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
                linePaint.color = MaterialColors.getColor(
                    requireView(),
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
                goalLinePaint.color = errorColor
//
                onValueFormat = { value -> "${value.toInt()}" }
            }

            xAxis.apply {
                increment = 86400000.0
//                displayCount = 168
//                displayCount = 10
                textPaint.color = MaterialColors.getColor(
                    requireView(),
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
                textPaint.textSize = 32f
                onValueFormat = onValueFormat@{
                    val formatter = DateFormat.getDateTimeInstance(
                        DateFormat.SHORT,
                        DateFormat.SHORT,
                        Locale.getDefault()
                    )
                    return@onValueFormat formatter.format(Date(it.toLong()))
                }

            }
        }

        viewModel.goal.observe(viewLifecycleOwner) {
            chart.yAxis.setGoalLine(it?.toFloat())
            chart.refresh()
        }

        viewModel.items.observe(viewLifecycleOwner) { list ->
            adapter.set(list)

            if (list.isEmpty()) {
                return@observe
            }



//            chart.animation.enabled = false
//            chart.animation.refreshRate = 60
//            chart.animation.duration = 300

//            chart.scroller.zoomEnabled = false

//            chart.xAxis.labels.size = 32f

            val entries: HashMap<Long, Entry> = HashMap()

            list.forEach {
                val cal = Calendar.getInstance(TimeZone.getTimeZone("UTC"))
                cal.timeInMillis = it.timestamp

                cal.set(Calendar.HOUR, 0)
                cal.set(Calendar.AM_PM, Calendar.AM)
                val ts = cal.timeInMillis
                if (!entries.containsKey(ts)) {
                    entries[ts] = Entry((ts).toDouble(), 0F, errorColor)
                }

                entries[ts]!!.y += it.value.toFloat()

                if (viewModel.goal.value != null) {
                    if (entries[ts]!!.y > viewModel.goal.value!!) {
                        entries[ts]!!.color = null
                    }
                } else {
                    entries[ts]!!.color = null
                }
            }

            serie.entries = ArrayList(entries.values)

            chart.xAxis.x = chart.xAxis.getXMax()


            chart.refresh()
        }
    }
}
