package com.dzeio.openhealth.ui.weight

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.Settings
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.weight.Weight
import com.dzeio.openhealth.data.weight.WeightRepository
import com.dzeio.openhealth.units.Units
import com.dzeio.openhealth.utils.Configuration
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ListWeightViewModel @Inject internal constructor(
    private val weightRepository: WeightRepository,
    private val settings: Configuration
) : BaseViewModel() {


    private val _massUnit = MutableLiveData(Units.Mass.KILOGRAM)
    val massUnit: LiveData<Units.Mass> = _massUnit

    private val _goalWeight = settings.getFloat(Settings.WEIGHT_GOAL)
    val goalWeight = _goalWeight.toLiveData()

    private val _weights = MutableLiveData<List<Weight>?>(null)
    val weights: LiveData<List<Weight>?> = _weights


    init {
        viewModelScope.launch {
            weightRepository.getWeights().collectLatest {
                _weights.postValue(it)
            }
        }

        settings.getString(Settings.MASS_UNIT).apply {
            addObserver {
                if (it == null) return@addObserver
                _massUnit.postValue(Units.Mass.find(it))
            }
            if (value != null) {
                _massUnit.postValue(Units.Mass.find(value!!))
            }
        }
    }
}
