package com.dzeio.openhealth.ui.weight

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.Settings
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.weight.Weight
import com.dzeio.openhealth.data.weight.WeightRepository
import com.dzeio.openhealth.units.Units
import com.dzeio.openhealth.utils.Configuration
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class WeightDialogViewModel @Inject internal constructor(
    private val weightRepository: WeightRepository,
    private val settings: Configuration
) : BaseViewModel() {

    private val _goalWeight = settings.getFloat(Settings.WEIGHT_GOAL)

    val goalWeight = _goalWeight.toLiveData()

    private val _weight = MutableLiveData<Weight?>(null)
    val weight: LiveData<Weight?> = _weight

    val format =
        Units.Mass.find(settings.getString(Settings.MASS_UNIT).value ?: Units.Mass.KILOGRAM.id)

    fun initWithWeight(id: Long?) {
        viewModelScope.launch {
            if (id != null) {
                weightRepository.getWeight(id).collectLatest {
                    _weight.postValue(it)
                }
            } else {
                weightRepository.lastWeight().collectLatest {
                    _weight.postValue(it)
                }

            }
        }
    }

    suspend fun addWeight(weight: Float) {
        weightRepository.addWeight(Weight(weight = weight / format.modifier))
    }

    fun setWeightGoal(value: Float?) {
        if (value != null) {
            _goalWeight.value = value / format.modifier
        } else {
            _goalWeight.value = null
        }
    }
}
