package com.dzeio.openhealth.workers

import android.app.PendingIntent
import android.content.Context
import android.os.Build
import android.util.Log
import androidx.core.app.NotificationCompat
import androidx.core.app.NotificationManagerCompat
import androidx.navigation.NavDeepLinkBuilder
import androidx.work.PeriodicWorkRequestBuilder
import androidx.work.WorkerParameters
import com.dzeio.openhealth.Application
import com.dzeio.openhealth.R
import com.dzeio.openhealth.core.BaseWorker
import com.dzeio.openhealth.interfaces.NotificationChannels
import com.dzeio.openhealth.interfaces.NotificationIds
import java.util.Date
import java.util.concurrent.TimeUnit

class WaterReminderWorker(
    private val context: Context,
    params: WorkerParameters
) : BaseWorker(context, params) {

    companion object {
        const val TAG = "${Application.TAG}/WaterWorker"
        fun setup(context: Context) {
            schedule(
                TAG,
                PeriodicWorkRequestBuilder<WaterReminderWorker>(1, TimeUnit.HOURS)
                    .addTag(TAG)
                    .build(),
                context
            )
        }
    }

    override fun doWork(): Result {
        Log.d(TAG, "Ran! ${Date().toLocaleString()}")
        with(NotificationManagerCompat.from(context)) {
            val flag =
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.S) PendingIntent.FLAG_IMMUTABLE else 0
            val intent = NavDeepLinkBuilder(context)
                .setGraph(R.navigation.mobile_navigation)
                .setDestination(R.id.nav_home)
                // Will nav to water home when there will be a way to add it there
                // .setDestination(R.id.nav_water_home)
                .createTaskStackBuilder()
                .getPendingIntent(0, flag)
            val builder =
                NotificationCompat.Builder(context, NotificationChannels.WATER.id)
                    .setContentTitle("Did you drink?")
                    .setContentText("Drink now! ${Date().toLocaleString()}")
                    .setSmallIcon(R.drawable.ic_logo_small)
                    .setPriority(NotificationCompat.PRIORITY_HIGH)
                    .setContentIntent(
                        intent
                    )
                    .build()
            notify(
                NotificationIds.WaterIntake.ordinal,
                builder
            )
        }
        return Result.success()
    }
}
